@@ -2,5 +2,5 @@
 UPDATE_SCRIPT=/usr/share/awstats/tools/update.sh
 if [ -x $UPDATE_SCRIPT ]
 then
-  su -l -c $UPDATE_SCRIPT www-data
+  su -s /bin/sh -l -c $UPDATE_SCRIPT www-data
 fi
